//unit numbering

#ifndef RCD_UNITS_H
#define RCD_UNITS_H 1

#define idMAIN      1
#define idEDID_MAIN 2
#define idEDID_BASE 3
#define idEDID_DESC 4
#define idCEA       5
#define idCEA_ET    6
#define idGRP_AR    7
#define idVMAP      8
#define idGUI_LOG  10

#endif /* RCD_UNITS_H */
